Zincblende ZnTe

Forces and NAC params were calculated using VASP code. PBEsol, 500eV PW-cutoff,
2x2x2 supercell and 2x2x2 off-Gamma k-point mesh for supercells.

`phono3py_params_ZnTe.yaml` contains all needed information to calculate thermal
conductivity.

`fc3.hdf5` and `fc2.hdf5` are generated by

```
% phono3py-load phono3py_params_ZnTe.yaml
```

Lattice thermal conductivity at 300K is calculated as 46.5 W/m-K by

```
% phono3py-load phono3py_params_ZnTe.yaml --mesh 50 --br --ts 300
```

The 14x14x14 sampling mesh is chosen by `--mesh 50`.
